/**
 * Configuration options for the Gemini MCP client
 */
export interface ClientMCPConfig {
  /**
   * Your Gemini MCP API key
   */
  apiKey: string;
  
  /**
   * Model name, e.g. "gemini-2.0-flash"
   */
  model: string;

  /**
   * Base URL for the Gemini MCP API (default: "https://generativelanguage.googleapis.com/v1beta/openai")
   */
  baseUrl: string;
  
  /**
   * Request timeout in milliseconds (default: 30000)
   */
  timeout?: number;
  
  /**
   * Enable debug logging (default: false)
   */
  debug?: boolean;

  /**
   * system messages
   */
  systemMessages?: string;
}




/**
 * Standard API response format
 */
export interface ApiResponse<T> {
  data?: T;
  error?: {
    code: string;
    message: string;
    details?: unknown;
  };
}

export type ChatChunk = {
  choices: Array<{
    delta: {
      content?: string;
      tool_calls?: Array<{
        function: {
          name?: string;
          arguments?: string;
        };
      }>;
    };
  }>;
};

// Export error types
export * from './errors';

